==> common-base-tools-v3-3.3.1-sources.jar: common/base/tools/statistics/QpsItem.java <==
package common.base.tools.statistics;

/**
 * @author Administrator
 */
public class QpsItem {

    private int  visitCount = 0;
    private long minDurationMs = Long.MAX_VALUE;
    private long maxDurationMs = Long.MIN_VALUE;
    private double avgDurationMs = 0;
    private long arriveTime = System.currentTimeMillis();

    public int getVisitCount() {
        return visitCount;
    }

    public void setVisitCount(int visitCount) {
        this.visitCount = visitCount;
    }

    public long getMinDurationMs() {
        return minDurationMs;
    }

    public void setMinDurationMs(long minDurationMs) {
        this.minDurationMs = minDurationMs;
    }

    public long getMaxDurationMs() {
        return maxDurationMs;
    }

    public void setMaxDurationMs(long maxDurationMs) {
        this.maxDurationMs = maxDurationMs;
    }

    public double getAvgDurationMs() {
        return avgDurationMs;
    }

    public void setAvgDurationMs(double avgDurationMs) {
        this.avgDurationMs = avgDurationMs;
    }

    public long getArriveTime() {
        return arriveTime;
    }

    public void setArriveTime(long arriveTime) {
        this.arriveTime = arriveTime;
    }

    @Override
    public String toString() {
        return "QpsItem{" +
                "visitCount=" + visitCount +
                ", minDurationMs=" + minDurationMs +
                ", maxDurationMs=" + maxDurationMs +
                ", avgDurationMs=" + avgDurationMs +
                ", arriveTime=" + arriveTime +
                '}';
    }
}

==> common-base-tools-v3-6.6.12-sources.jar: common/base/tools/statistics/QpsItem.java <==
package common.base.tools.statistics;

/**
 * @author Administrator
 */
public class QpsItem {

    private int  visitCount = 0;
    private long minDurationMs = Long.MAX_VALUE;
    private long maxDurationMs = Long.MIN_VALUE;
    private double avgDurationMs = 0;
    private long arriveTime = 0;

    public int getVisitCount() {
        return visitCount;
    }

    public void setVisitCount(int visitCount) {
        this.visitCount = visitCount;
    }

    public long getMinDurationMs() {
        return minDurationMs;
    }

    public void setMinDurationMs(long minDurationMs) {
        this.minDurationMs = minDurationMs;
    }

    public long getMaxDurationMs() {
        return maxDurationMs;
    }

    public void setMaxDurationMs(long maxDurationMs) {
        this.maxDurationMs = maxDurationMs;
    }

    public double getAvgDurationMs() {
        return avgDurationMs;
    }

    public void setAvgDurationMs(double avgDurationMs) {
        this.avgDurationMs = avgDurationMs;
    }

    public long getArriveTime() {
        return arriveTime;
    }

    public void setArriveTime(long arriveTime) {
        this.arriveTime = arriveTime;
    }

    @Override
    public String toString() {
        return "QpsItem{" +
                "visitCount=" + visitCount +
                ", minDurationMs=" + minDurationMs +
                ", maxDurationMs=" + maxDurationMs +
                ", avgDurationMs=" + avgDurationMs +
                ", arriveTime=" + arriveTime +
                '}';
    }
}
